﻿namespace TestProject1
{
    /// <summary>
    /// Class to handle creating email-related strings.
    /// </summary>
    public class EmailAddressManager
    {
        /// <summary>
        /// Domain name to be used in email creation.
        /// </summary>
        private readonly string domain;

        /// <summary>
        /// Create a new instance and store the specified domain name.
        /// </summary>
        /// <param name="domain">Domain name to be used in email creation</param>
        public EmailAddressManager(string domain)
        {
            this.domain = domain;
        }

        /// <summary>
        /// Create a new, unique email ID. Uniqueness is achievied by creating
        /// a random first name, last name, and adding a current date/time stamp.
        /// </summary>
        /// <returns>New email ID string</returns>
        public string CreateNewEmailId()
        {
            var firstName = Faker.Name.First();
            var lastName = Faker.Name.Last();
            var currDateTime = DateTime.Now.ToString("yyyyMMddHHmmss");

            return $"{firstName}.{lastName}.{currDateTime}";
        }

        /// <summary>
        /// Create a new, unique email address based on the specified email ID and
        /// the previously specified email domain.
        /// </summary>
        /// <param name="emailId">Email ID to be used in addreess creation</param>
        /// <returns>New email address string</returns>
        public string CreateEmailAddress(string emailId)
        {
            return $"{emailId}@{this.domain}";
        }
    }
}
